@@ -210,6 +210,10 @@ types: list[str] = [
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
+    "AWS::EC2::NetworkInsightsAccessScope",
+    "AWS::EC2::NetworkInsightsAccessScopeAnalysis",
+    "AWS::EC2::NetworkInsightsAnalysis",
+    "AWS::EC2::NetworkInsightsPath",
     "AWS::EC2::NetworkInterface",
     "AWS::EC2::NetworkInterfaceAttachment",
     "AWS::EC2::NetworkInterfacePermission",
@@ -350,6 +354,7 @@ types: list[str] = [
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
     "AWS::Glue::Workflow",
+    "AWS::GreengrassV2::Deployment",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
     "AWS::GuardDuty::IPSet",
@@ -383,18 +388,31 @@ types: list[str] = [
     "AWS::ImageBuilder::ImageRecipe",
     "AWS::ImageBuilder::InfrastructureConfiguration",
     "AWS::ImageBuilder::Workflow",
+    "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
+    "AWS::IoT::BillingGroup",
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
+    "AWS::IoT::CustomMetric",
+    "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
+    "AWS::IoT::FleetMetric",
+    "AWS::IoT::JobTemplate",
+    "AWS::IoT::MitigationAction",
     "AWS::IoT::Policy",
     "AWS::IoT::PolicyPrincipalAttachment",
     "AWS::IoT::ProvisioningTemplate",
     "AWS::IoT::RoleAlias",
+    "AWS::IoT::ScheduledAudit",
+    "AWS::IoT::SecurityProfile",
     "AWS::IoT::Thing",
+    "AWS::IoT::ThingGroup",
     "AWS::IoT::ThingPrincipalAttachment",
+    "AWS::IoT::ThingType",
     "AWS::IoT::TopicRule",
+    "AWS::IoT::TopicRuleDestination",
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
@@ -403,6 +421,8 @@ types: list[str] = [
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
     "AWS::KinesisFirehose::DeliveryStream",
+    "AWS::KinesisVideo::SignalingChannel",
+    "AWS::KinesisVideo::Stream",
     "AWS::LakeFormation::DataCellsFilter",
     "AWS::LakeFormation::DataLakeSettings",
     "AWS::LakeFormation::Permissions",
@@ -711,7 +731,6 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
-    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -832,6 +851,10 @@ cached: list[str] = [
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinsightsaccessscope.json",
+    "aws-ec2-networkinsightsaccessscopeanalysis.json",
+    "aws-ec2-networkinsightsanalysis.json",
+    "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
@@ -912,14 +935,17 @@ cached: list[str] = [
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
+    "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
+    "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
+    "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
     "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
@@ -957,6 +983,7 @@ cached: list[str] = [
     "aws-glue-table.json",
     "aws-glue-trigger.json",
     "aws-glue-workflow.json",
+    "aws-greengrassv2-deployment.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
     "aws-guardduty-ipset.json",
@@ -989,19 +1016,35 @@ cached: list[str] = [
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
+    "aws-iot-accountauditconfiguration.json",
     "aws-iot-authorizer.json",
+    "aws-iot-billinggroup.json",
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
+    "aws-iot-custommetric.json",
+    "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
+    "aws-iot-fleetmetric.json",
+    "aws-iot-jobtemplate.json",
     "aws-iot-policy.json",
     "aws-iot-provisioningtemplate.json",
     "aws-iot-rolealias.json",
+    "aws-iot-scheduledaudit.json",
+    "aws-iot-securityprofile.json",
+    "aws-iot-thing.json",
+    "aws-iot-thinggroup.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-iot-thingtype.json",
+    "aws-iot-topicrule.json",
+    "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
+    "aws-kinesisvideo-signalingchannel.json",
+    "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
@@ -1019,6 +1062,7 @@ cached: list[str] = [
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-location-apikey.json",
     "aws-location-geofencecollection.json",
@@ -1030,6 +1074,8 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
+    "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1070,7 +1116,6 @@ cached: list[str] = [
     "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -1094,7 +1139,6 @@ cached: list[str] = [
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
-    "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
