@@ -991,6 +991,8 @@ types: list[str] = [
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
+    "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::Omics::AnnotationStore",
     "AWS::Omics::ReferenceStore",
     "AWS::Omics::RunGroup",
@@ -1420,6 +1422,7 @@ types: list[str] = [
     "AWS::WorkSpacesWeb::IpAccessSettings",
     "AWS::WorkSpacesWeb::NetworkSettings",
     "AWS::WorkSpacesWeb::Portal",
+    "AWS::WorkSpacesWeb::SessionLogger",
     "AWS::WorkSpacesWeb::TrustStore",
     "AWS::WorkSpacesWeb::UserAccessLoggingSettings",
     "AWS::WorkSpacesWeb::UserSettings",
